#
# spec file for package perl-Net-SSLGlue
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Net-SSLGlue
Version:        1.058
Release:        1.25
%define cpan_name Net-SSLGlue
Summary:        Add/Extend Ssl Support for Common Perl Modules
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Net-SSLGlue/
Source0:        http://www.cpan.org/authors/id/S/SU/SULLR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IO::Socket::SSL) >= 1.19
Requires:       perl(IO::Socket::SSL) >= 1.19
%{perl_requires}

%description
Some commonly used perl modules don't have SSL support at all, even if the
protocol supports it. Others have SSL support, but most of them don't do
proper checking of the server's certificate.

The 'Net::SSLGlue::*' modules try to add SSL support or proper certificate
checking to these modules. Currently support for the following modules is
available:

* Net::SMTP - add SSL from beginning or using STARTTLS

* Net::POP3 - add SSL from beginning or using STLS

* Net::FTP  - add SSL and IPv6 support to Net::FTP

* Net::LDAP - add proper certificate checking

* LWP - add proper certificate checking for older LWP versions

There is also a Net::SSLGlue::Socket package which combines ssl and non-ssl
and ipv6 capabilities to make it easier to enhance modules based on
IO::Socket::INET.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes COPYRIGHT examples README

%changelog
* Thu Jun 23 2016 coolo@suse.com
- updated to 1.058
  see /usr/share/doc/packages/perl-Net-SSLGlue/Changes
  1.058 2016/06/17
  - RT#109887 - fix t/01_load.t in case only very old version of LWP was
    installed which did not have LWP::Protocol::https
* Thu Apr  7 2016 coolo@suse.com
- updated to 1.057
  see /usr/share/doc/packages/perl-Net-SSLGlue/Changes
  1.057 2016/04/04
  - removed warning with very old versions of LWP where
    LWP::Protocol::https::VERSION was not defined yet.
    Thanks to denis[AT]fateyev[DOT]com for reporting
  1.056 2015/10/31
  - fix another memory leak which happened on data connections only
  - make sure that context reuse is done properly, see
    https://github.com/noxxi/p5-net-sslglue/pull/3
* Fri Nov  6 2015 coolo@suse.com
- updated to 1.055
  see /usr/share/doc/packages/perl-Net-SSLGlue/Changes
  1.055 2015/10/25
  - fix memory leak in Net::SSLGlue::Socket, RT#107816.
    Thanks to kasyap.mr[AT]gmail[DOT]com  for reporting
* Wed Apr 29 2015 coolo@suse.com
- updated to 1.054
  see /usr/share/doc/packages/perl-Net-SSLGlue/Changes
  1.054 2015/04/28
  - if a version of libnet is detected which already supports TLS (i.e.
    libnet 3.0+) warn and use this instead.
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.053
  see /usr/share/doc/packages/perl-Net-SSLGlue/Changes
  1.053 2014/05/28
  - if current LWP is detected is use this mostly unpatched
  - fix Net::SSLGlue::FTP to use the same hostname when verifying the
    certificate of the data connection
  1.052 2014/01/16
  - FTPS: reuse same SSL session for control and data channnel to work
    with default configuration of proftpd.
  1.051 2014/01/10
  - fixes to Net::FTP SSL support
  - examples/ftps-tests.pl has lots of tests for FTP against live server
  1.05 2014/01/09
  - added support for SSL+IPv6 in Net::FTP
  - new package Net::SSLGlue::Socket for a socket which combines plain,ssl,ipv6
  - fixed some tests - some checks for bad certificates do not work anymore
    because these certs were fixed
* Wed Dec 18 2013 coolo@suse.com
- updated to 1.04
  replace Net::Cmd::getline via Net::SSLGlue::POP3 because it assumed, that it
  just needs to wait for read events on the sockets - which is not the case for
  SSL (e.g. SSL_WANT_READ, SSL_WANT_WRITE).
  Fixes https://rt.cpan.org/Ticket/Display.html?id=87507.
  fixed documentation for Net::SSLGlue::POP3
  added Net::SSLGlue::POP3
* Sun May  5 2013 mc@suse.com
- update to version 1.01
  * Net::SSLGlue::LDAP as wrongly named Net::DNSGlue::LDAP
  * Net::SSLGlue::SMTP: save hello domain from last hello call, so that the
    hello after the starttls uses the same domain argument.
  * Net::SSLGlue::SMTP: fixed stripping of port from host/ip for name
    verification. Added hello after successful starttls. Extented tests
    to check, if we can actually talk after starttls.
  * fixed wrong position for include encode_base64 and uri_unescape in *::LWP.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed May  4 2011 coolo@opensuse.org
- updated to 0.6
  fixed english, thanks to dom, https://rt.cpan.org/Ticket/Display.html?id=46284
* Thu Mar 31 2011 coolo@novell.com
- update to 0.5:
  documentation fixes: http://rt.cpan.org/Ticket/Display.html?id=65258
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul 20 2010 chris@computersalat.de
- update to 0.4
  * added Changes, put examples into examples/ dir
- 0.3 2010/05/13
  * rewrite parts of Net::SSLGlue::LWP so that it sends the correct request
    to the peer even if https_proxy is used. In former version it ommitted
    the HTTP version number in the request (thus the request was invalid).
    Bug report by PMOONEY https://rt.cpan.org/Ticket/Display.html?id=57365
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon May 18 2009 mc@suse.de
- initial version 0.2
